from tvpy.console import cls
from tvpy.tv_clean import tv_clean
from tvpy.tv_download import tv_download
from tvpy.tv_follow import read_follow
from tvpy.tv_info import tv_info
from tvpy.tv_rename import tv_rename
from tvpy.tv_subs import tv_subs
from tvpy.tv_tmdb import tv_tmdb

logo = (r'''
📺📺📺📺📺📺📺📺📺📺📺📺📺📺
[yellow2]  _______    _____       
[yellow2] |__   __|  |  __ \      
[yellow2]    | |_   _| |__) |   _ 
[yellow2]    | \ \ / /  ___/ | | |
[yellow2]    | |\ V /| |   | |_| |
[yellow2]    |_| \_/ |_|    \__, |
[yellow2]                    __/ |
[yellow2]                   |___/ 

🥧🥧🥧🥧🥧🥧🥧🥧🥧🥧🥧🥧🥧                                                        
''')


def tvpy(folder=None, k=10):
    def sep(title):
        cls.print()
        cls.print(f'[dim orchid1]{title}')

    cls.print(logo)

    folders = read_follow() if folder is None else [folder]

    for folder in folders:
        cls.print(f'[yellow2 bold] {folder}')

        sep('Generating .tvpy.json')
        tv_tmdb(folder)

        sep('Downloading episodes')
        tv_download(folder, k=k)

        sep('Renaming files')
        tv_rename(folder)

        sep('Downloading subtitles')
        tv_subs(folder)

        sep('Removing unused files')
        tv_clean(folder)

        tv_info(folder)



from pathlib import Path

from tvpy.config import default, load_config, save_config


def read_follow():
    config = load_config()
    tvpy_home = Path(config[default.TVPY_HOME.name])
    tvpy_home.mkdir(parents=True, exist_ok=True)
    follows = set()
    for follow_txt in config[default.follow.name]:
        with open(follow_txt, 'r') as f:
            follows |= set(f.read().splitlines())

    return [tvpy_home / f for f in follows]


def tv_follow(file):
    '''follow a file

    Args:
        file: follow this file
    '''
    path = str(Path(file).absolute())
    config = load_config()
    config[default.follow.name] = list(set(config[default.follow.name] + [path]))
    save_config(config)



from pprint import pprint

from py1337x import py1337x

torrents = py1337x()


def show_status(local):
    torrent = local.status()
    print("\r{:.2f}% complete (down: {:.1f} kB/s up: {:.1f} kB/s peers: {:d}) {}".format(
        torrent.progress * 100,
        torrent.download_rate / 1000,
        torrent.upload_rate / 1000,
        torrent.num_peers,
        torrent.state), end=" ")


if __name__ == '__main__':
    res = torrents.search('Andor S01E01')
    pprint(res)
    # s = lt.session()
    # magnet_uri = 'magnet:?xt=urn:btih:7AEE6A3FD1DBC0DE5031638C6F40314FAB8E79E4&dn=Accident+Man%3A+Hitman%27s+Holiday+%282022%29+%5B720p%5D+%5BYTS.MX%5D&tr=udp%3A%2F%2Ftracker.opentrackr.org%3A1337%2Fannounce&tr=udp%3A%2F%2Ftracker.leechers-paradise.org%3A6969%2Fannounce&tr=udp%3A%2F%2F9.rarbg.to%3A2710%2Fannounce&tr=udp%3A%2F%2Fp4p.arenabg.ch%3A1337%2Fannounce&tr=udp%3A%2F%2Ftracker.cyberia.is%3A6969%2Fannounce&tr=http%3A%2F%2Fp4p.arenabg.com%3A1337%2Fannounce&tr=udp%3A%2F%2Ftracker.internetwarriors.net%3A1337%2Fannounce'
    # params = lt.parse_magnet_uri(magnet_uri)
    # params.save_path = '/tmp'
    # local = s.add_torrent(params)

    # while True:
    #     show_status(local)
    # info = lt.torrent_info('/tmp/movie/movie.mp4')
    # print(info)
    # lt.make_magnet_uri()
